@@ -26,7 +26,7 @@ class Gui:
 
     def setup(self):
  
-        gtk.set_application_name("Peng Audiobook Player") # window title
+        gtk.set_application_name("nQa Audiobook Player") # window title
         self.win = hildon.StackableWindow()
    
         #Box that divides the layout in two: cover on the lefta
@@ -42,7 +42,7 @@ class Gui:
         # Controls:
 
         # Label that hold the title of the book,and maybe the chapter
-        self.title = gtk.Label("No menu option has been selected yet.")
+        self.title = gtk.Label("Select a book to start listening")
         self.title.set_justify(gtk.JUSTIFY_CENTER)
             
         # Seekbar 
@@ -200,7 +200,10 @@ class Gui:
         #self.book_selector.clear()
         for b in books:
             self.book_selector.append_text(b)
+        if len(books)==0:
+            hildon.hildon_banner_show_information(self.win, "", "No audiobooks found. \nPlease place your audiobooks in the directory ~/MyDocs/Audiobooks")
 
+            
     def set_book(self,book,cover):
         self.button.set_text("Play", "Start playing the audiobook") # reset button
         self.title.set_text(book)
