@@ -8,7 +8,7 @@ import SimpleGStreamer
 import Paths
 
 import logging
-log = logging.getLogger("pap.Controller")
+log = logging.getLogger("nqaap.Controller")
 
 class Player:
     def __init__(self,ui = None, threaded = False):
@@ -78,8 +78,8 @@ class Player:
         self.player.stop()
         
         #print "stopped at ", position
-
-        self.storage.set_time(self.audiobook.current_chapter, position)
+        if not self.audiobook is None:
+            self.storage.set_time(self.audiobook.current_chapter, position)
 
 
 
